@@ -12,6 +12,7 @@ OC.L10N.register(
     "{actor} invited you to {call}" : "{actor} te ha invitado a {call}",
     "Talk" : "Hablar",
     "Guest" : "Invitado",
+    "Message deleted by author" : "Mensaje borrado por el autor",
     "Administration" : "Administración",
     "System" : "Sistema",
     "Talk to %s" : "Hablar con %s",
@@ -22,6 +23,7 @@ OC.L10N.register(
     "Description" : "Descripción",
     "Accept" : "Aceptar",
     "Decline" : "Declinar",
+    "New message" : "Mensaje nuevo",
     "Join call" : "Unirse a la llamada",
     "A group call has started in {call}" : "Una llamada en grupo ha iniciado en {call}",
     "Open settings" : "Abrir configuraciones",
