@@ -278,6 +278,7 @@ OC.L10N.register(
     "Reset" : "Setel ulang",
     "Back" : "Kembali",
     "Cancel" : "Membatalkan",
+    "Now" : "Sekarang",
     "Loading …" : "Memuat …",
     "Calendar" : "Kalender",
     "Attendees" : "Peserta",
@@ -298,6 +299,7 @@ OC.L10N.register(
     "Restricted" : "Terbatas",
     "Meeting" : "Rapat",
     "Personal" : "Pribadi",
+    "_%n hour_::_%n hours_" : ["%n jam"],
     "Password protection" : "Password protection",
     "Edit" : "Sunting",
     "Delete" : "Hapus",
