@@ -76,6 +76,9 @@ OC.L10N.register(
     "Dismiss notification" : "Afgreiða tilkynningu",
     "Accept" : "Samþykkja",
     "Decline" : "Hafna",
+    "New message" : "Ný skilaboð",
+    "Reminder" : "Áminning",
+    "Notification" : "Tilkynning",
     "{user} sent you a private message" : "{user} sendi þér einkaskilaboð",
     "{user} sent a message in conversation {call}" : "{user} sendi skilaboð í samtali {call}",
     "A deleted user sent a message in conversation {call}" : "Eyddur notandi sendi skilaboð í samtali {call}",
@@ -236,6 +239,7 @@ OC.L10N.register(
     "Saint Martin (French part)" : "Sankti Martin (franski hluti)",
     "Madagascar" : "Madagaskar",
     "Marshall Islands" : "Marshall eyjar",
+    "North Macedonia" : "Norður-Makedónía",
     "Mali" : "Malí",
     "Myanmar" : "Mjanmar",
     "Mongolia" : "Mongólía",
@@ -395,7 +399,6 @@ OC.L10N.register(
     "Cancel" : "Hætta við",
     "Now" : "Núna",
     "Loading …" : "Hleð inn …",
-    "No upcoming events" : "Engir atburðir á næstunni",
     "From" : "Frá",
     "To" : "Til",
     "Calendar" : "Dagatal",
@@ -428,8 +431,8 @@ OC.L10N.register(
     "Choose" : "Velja",
     "The file must be a PNG or JPG" : "Skráin verður að vera PNG eða JPG",
     "Restricted" : "Takmarkað",
-    "Personal" : "Persónulegt",
     "Meeting" : "Fundur",
+    "Personal" : "Persónulegt",
     "Leave conversation" : "Hætta í samtali",
     "Delete conversation" : "Eyða samtali",
     "_%n hour_::_%n hours_" : ["%n klukkustund","%n klukkustundir"],
@@ -441,6 +444,8 @@ OC.L10N.register(
     "Delete" : "Eyða",
     "Log content" : "Efni atvikaskrár",
     "Notifications" : "Tilkynningar",
+    "Join" : "Taka þátt",
+    "Create a new conversation" : "Hefja nýtt samtal",
     "Enter your name" : "Settu inn nafnið þitt",
     "Log in" : "Skrá inn",
     "Mark as read" : "Merkja sem lesið",
@@ -450,7 +455,7 @@ OC.L10N.register(
     "You need to promote a new moderator before you can leave the conversation." : "Þú þarft að uppfæra einhvern í stöðu umsjónarmanna áður en þú getur hætt í samtalinu.",
     "Unread" : "Ólesið",
     "No matches found" : "Engar samsvaranir fundust",
-    "Create a new conversation" : "Hefja nýtt samtal",
+    "Unread messages" : "Ólesin skilaboð",
     "Clear filter" : "Hreinsa síu",
     "Users" : "Notendur",
     "Groups" : "Hópar",
@@ -460,6 +465,7 @@ OC.L10N.register(
     "You are currently waiting in the lobby" : "You are currently waiting in the lobby",
     "None" : "Enginn",
     "Select a device" : "Veldu tæki",
+    "Test" : "Prófun",
     "Devices" : "Tæki",
     "No audio" : "Ekkert hljóð",
     "Invalid path selected" : "Ógild slóð valin",
@@ -467,7 +473,6 @@ OC.L10N.register(
     "Upload" : "Senda inn",
     "Files" : "Skrár",
     "Message sent" : "Skilaboðin hafa verið send",
-    "Unread messages" : "Ólesin skilaboð",
     "Later today – {timeLocale}" : "Síðar í dag – {timeLocale}",
     "Set reminder for later today" : "Setja áminningu seinna í dag",
     "Tomorrow – {timeLocale}" : "Á morgun – {timeLocale}",
@@ -506,8 +511,8 @@ OC.L10N.register(
     "Add participants" : "Bæta við þátttakanda",
     "Enter password" : "Enter password",
     "Send message" : "Senda skilaboð",
-    "Add emoji" : "Bæta við tjáningartákni",
     "File to share" : "Skrá til að deila",
+    "Add emoji" : "Bæta við tjáningartákni",
     "Share from Files" : "Deila úr skrám",
     "Upload from device" : "Senda inn frá tæki",
     "Create new poll" : "Búa til nýja könnun",
@@ -519,7 +524,6 @@ OC.L10N.register(
     "Settings" : "Stillingar",
     "Anonymous poll" : "Nafnlaus könnun",
     "End poll" : "End poll",
-    "Join" : "Taka þátt",
     "moderator" : "umsjónarmaður",
     "guest" : "gestanotandi",
     "Remove participant" : "Fjarlægja þátttakanda",
@@ -555,6 +559,7 @@ OC.L10N.register(
     "Show your screen" : "Birta skjáinn þinn",
     "Stop screensharing" : "Hætta skjádeilingu",
     "Grid view" : "Reitasýn",
+    "Keep" : "Halda",
     "Select a region" : "Veldu svæði",
     "Submit" : "Senda inn",
     "Duplicate session" : "Duplicate session",
