@@ -10,6 +10,7 @@ OC.L10N.register(
     "Invalid image" : "Ugyldig bilete",
     "Unknown filetype" : "Ukjend filtype",
     "Say hi to your friends and colleagues!" : "Sei hei til dine venner og kollegar!",
+    "Description" : "Skildring",
     "Open settings" : "Opne instillingar",
     "Messages" : "Meldingar",
     "Albania" : "Albania",
@@ -50,7 +51,6 @@ OC.L10N.register(
     "Everyone" : "Alle",
     "Disabled" : "Deaktivert",
     "Name" : "Namn",
-    "Description" : "Skildring",
     "Enable encryption" : "Aktiver kryptering",
     "Pending" : "Under vegs",
     "Error" : "Feil",
@@ -78,16 +78,17 @@ OC.L10N.register(
     "More information" : "Meir informasjon",
     "Delete" : "Slett",
     "Notifications" : "Varsel",
+    "Important conversation" : "Viktig samtale",
     "Log in" : "Logg inn",
     "Remove from favorites" : "Remove from favorites",
     "Add to favorites" : "Add to favorites",
+    "Unread messages" : "Meldingar er ikkje lest",
     "Users" : "Brukarare",
     "Groups" : "Grupper",
     "None" : "Ingen",
     "Upload" : "Last opp",
     "Files" : "Filer",
     "Message sent" : "Melding sendt",
-    "Unread messages" : "Meldingar er ikkje lest",
     "Reply" : "Svare",
     "Reply privately" : "Svar privat",
     "Dismiss" : "Forkast",
@@ -128,8 +129,6 @@ OC.L10N.register(
     "The password is wrong. Try again." : "Passordet er gale. Prøv igjen.",
     "__language_name__" : "Nynorsk",
     "Tasks" : "Oppgåver",
-    "Loading" : "Loading",
-    "Close" : "Lukk",
-    "Password protect" : "Vern med passord"
+    "Close" : "Lukk"
 },
 "nplurals=2; plural=(n != 1);");
