@@ -296,6 +296,8 @@ OC.L10N.register(
     "No" : "Não",
     "Yes" : "Sim",
     "Delete conversation" : "Eliminar conversação",
+    "_%n hour_::_%n hours_" : ["%n hora","%n horas","%n horas"],
+    "_%n day_::_%n days_" : ["%n dia","%n dias","%n dias"],
     "Password protection" : "Protegido por palavra-passe",
     "Set a password" : "Definir uma palavra-passe",
     "Edit" : "Editar",
@@ -313,7 +315,9 @@ OC.L10N.register(
     "Groups" : "Grupos",
     "Teams" : "Grupos",
     "None" : "Nenhum",
+    "Test" : "Teste",
     "Invalid path selected" : "Caminho inválido selecionado",
+    "Blur" : "Blur",
     "Upload" : "Enviar",
     "Files" : "Ficheiros",
     "Message forwarded to \"Note to self\"" : "Mensagem reencaminhada para \"Nota a mim\"",
@@ -346,10 +350,12 @@ OC.L10N.register(
     "Chat" : "Conversa",
     "Details" : "Detalhes",
     "Search in {name}" : "Procurar em {name}",
+    "No results found" : "No results found",
     "Load more results" : "Mostrar mais resultados",
     "Projects" : "Projectos",
     "No shared items" : "Sem itens partilhados",
     "Privacy" : "Privacidade",
+    "Performance" : "Performance",
     "Keyboard shortcuts" : "Atalhos de teclado",
     "Search" : "Pesquisa sobre",
     "Screensharing options" : "Opções de partilha de ecrã",
