@@ -114,6 +114,14 @@ class Capabilities implements IPublicCapability {
 		'call-notification-state-api',
 		'schedule-meeting',
 		'edit-draft-poll',
+		'conversation-creation-all',
+		'important-conversations',
+		'unbind-conversation',
+		'sip-direct-dialin',
+		'dashboard-event-rooms',
+		'mutual-calendar-events',
+		'upcoming-reminders',
+		'sensitive-conversations',
 	];
 
 	public const CONDITIONAL_FEATURES = [
@@ -137,6 +145,13 @@ class Capabilities implements IPublicCapability {
 		'chat-summary-api',
 		'call-notification-state-api',
 		'schedule-meeting',
+		'conversation-creation-all',
+		'important-conversations',
+		'sip-direct-dialin',
+		'dashboard-event-rooms',
+		'mutual-calendar-events',
+		'upcoming-reminders',
+		'sensitive-conversations',
 	];
 
 	public const LOCAL_CONFIGS = [
@@ -146,6 +161,7 @@ class Capabilities implements IPublicCapability {
 		],
 		'call' => [
 			'predefined-backgrounds',
+			'predefined-backgrounds-v2',
 			'can-upload-background',
 			'start-without-media',
 			'blur-virtual-background',
@@ -175,6 +191,9 @@ class Capabilities implements IPublicCapability {
 			'session-ping-limit',
 			'hello-v2-token-key',
 		],
+		'experiments' => [
+			'enabled',
+		],
 	];
 
 	protected ICache $talkCache;
@@ -219,6 +238,7 @@ class Capabilities implements IPublicCapability {
 					'recording-consent' => $this->talkConfig->recordingConsentRequired(),
 					'supported-reactions' => ['❤️', '🎉', '👏', '👋', '👍', '👎', '🔥', '😂', '🤩', '🤔', '😲', '😥'],
 					// 'predefined-backgrounds' => list<string>,
+					// 'predefined-backgrounds-v2' => list<string>,
 					'can-upload-background' => false,
 					'sip-enabled' => $this->talkConfig->isSIPConfigured(),
 					'sip-dialout-enabled' => $this->talkConfig->isSIPDialOutEnabled(),
@@ -241,6 +261,9 @@ class Capabilities implements IPublicCapability {
 					'force-passwords' => $this->talkConfig->isPasswordEnforced(),
 					'list-style' => $this->talkConfig->getConversationsListStyle($user?->getUID()),
 					'description-length' => Room::DESCRIPTION_MAXIMUM_LENGTH,
+					'retention-event' => max(0, $this->appConfig->getAppValueInt('retention_event_rooms', 28)),
+					'retention-phone' => max(0, $this->appConfig->getAppValueInt('retention_phone_rooms', 7)),
+					'retention-instant-meetings' => max(0, $this->appConfig->getAppValueInt('retention_instant_meetings', 1)),
 				],
 				'federation' => [
 					'enabled' => false,
@@ -255,6 +278,9 @@ class Capabilities implements IPublicCapability {
 					'session-ping-limit' => max(0, (int)$this->serverConfig->getAppValue('spreed', 'session-ping-limit', '200')),
 					// 'hello-v2-token-key' => string,
 				],
+				'experiments' => [
+					'enabled' => max(0, $this->appConfig->getAppValueInt($user instanceof IUser ? 'experiments_users' : 'experiments_guests')),
+				],
 			],
 			'config-local' => self::LOCAL_CONFIGS,
 			'version' => $this->appManager->getAppVersion('spreed'),
@@ -289,46 +315,34 @@ class Capabilities implements IPublicCapability {
 			$capabilities['config']['signaling']['hello-v2-token-key'] = $pubKey;
 		}
 
-		/** @var ?list<string> $predefinedBackgrounds */
-		$predefinedBackgrounds = null;
-		$cachedPredefinedBackgrounds = $this->talkCache->get('predefined_backgrounds');
-		if ($cachedPredefinedBackgrounds !== null) {
-			// Try using cached value
-			/** @var list<string>|null $predefinedBackgrounds */
-			$predefinedBackgrounds = json_decode($cachedPredefinedBackgrounds, true);
+		$includeBrandedBackgrounds = $user instanceof IUser || $this->appConfig->getAppValueBool('backgrounds_branded_for_guests');
+		$includeDefaultBackgrounds = !$user instanceof IUser || $this->appConfig->getAppValueBool('backgrounds_default_for_users', true);
+
+		$predefinedBackgrounds = [];
+		$defaultBackgrounds = $this->getBackgroundsFromDirectory(__DIR__ . '/../img/backgrounds', '_default');
+		if ($includeBrandedBackgrounds) {
+			$predefinedBackgrounds = $this->getBackgroundsFromDirectory(\OC::$SERVERROOT . '/themes/talk-backgrounds', '_branded');
+			$predefinedBackgrounds = array_map(static fn ($fileName) => '/themes/talk-backgrounds/' . $fileName, $predefinedBackgrounds);
 		}
 
-		if (!is_array($predefinedBackgrounds)) {
-			// Cache was empty or invalid, regenerate
-			/** @var list<string> $predefinedBackgrounds */
-			$predefinedBackgrounds = [];
-			if (file_exists(__DIR__ . '/../img/backgrounds')) {
-				$directoryIterator = new \DirectoryIterator(__DIR__ . '/../img/backgrounds');
-				foreach ($directoryIterator as $file) {
-					if (!$file->isFile()) {
-						continue;
-					}
-					if ($file->isDot()) {
-						continue;
-					}
-					if ($file->getFilename() === 'COPYING') {
-						continue;
-					}
-					$predefinedBackgrounds[] = $file->getFilename();
-				}
-				sort($predefinedBackgrounds);
-			}
-
-			$this->talkCache->set('predefined_backgrounds', json_encode($predefinedBackgrounds), 300);
+		if ($includeDefaultBackgrounds) {
+			$spreedWebPath = $this->appManager->getAppWebPath('spreed');
+			$prefixedDefaultBackgrounds = array_map(static fn ($fileName) => $spreedWebPath . '/img/backgrounds/' . $fileName, $defaultBackgrounds);
+			$predefinedBackgrounds = array_merge($predefinedBackgrounds, $prefixedDefaultBackgrounds);
 		}
 
-		$capabilities['config']['call']['predefined-backgrounds'] = $predefinedBackgrounds;
+		$capabilities['config']['call']['predefined-backgrounds'] = $defaultBackgrounds;
+		$capabilities['config']['call']['predefined-backgrounds-v2'] = array_values($predefinedBackgrounds);
+
 		if ($user instanceof IUser) {
-			$quota = $user->getQuota();
-			if ($quota !== 'none') {
-				$quota = Util::computerFileSize($quota);
+			$userAllowedToUpload = $this->appConfig->getAppValueBool('backgrounds_upload_users', true);
+			if ($userAllowedToUpload) {
+				$quota = $user->getQuota();
+				if ($quota !== 'none') {
+					$quota = Util::computerFileSize($quota);
+				}
+				$capabilities['config']['call']['can-upload-background'] = $quota === 'none' || $quota > 0;
 			}
-			$capabilities['config']['call']['can-upload-background'] = $quota === 'none' || $quota > 0;
 			$capabilities['config']['call']['can-enable-sip'] = $this->talkConfig->canUserEnableSIP($user);
 		}
 
@@ -348,4 +362,43 @@ class Capabilities implements IPublicCapability {
 			'spreed' => $capabilities,
 		];
 	}
+
+	/**
+	 * @return list<string>
+	 */
+	protected function getBackgroundsFromDirectory(string $directory, string $cacheSuffix): array {
+		$cacheKey = 'predefined_backgrounds' . $cacheSuffix;
+
+		/** @var ?list<string> $predefinedBackgrounds */
+		$predefinedBackgrounds = null;
+		$cachedPredefinedBackgrounds = $this->talkCache->get($cacheKey);
+		if ($cachedPredefinedBackgrounds !== null) {
+			// Try using cached value
+			/** @var list<string>|null $predefinedBackgrounds */
+			$predefinedBackgrounds = json_decode($cachedPredefinedBackgrounds, true);
+		}
+
+		if (!is_array($predefinedBackgrounds)) {
+			if (file_exists($directory) && is_dir($directory)) {
+				$directoryIterator = new \DirectoryIterator($directory);
+				foreach ($directoryIterator as $file) {
+					if (!$file->isFile()) {
+						continue;
+					}
+					if ($file->isDot()) {
+						continue;
+					}
+					if ($file->getFilename() === 'COPYING') {
+						continue;
+					}
+					$predefinedBackgrounds[] = $file->getFilename();
+				}
+				sort($predefinedBackgrounds);
+			}
+
+			$this->talkCache->set($cacheKey, json_encode($predefinedBackgrounds), 300);
+		}
+
+		return $predefinedBackgrounds ?? [];
+	}
 }
