@@ -17,8 +17,10 @@ use OCA\Talk\Chat\Notifier;
 use OCA\Talk\Chat\ReactionManager;
 use OCA\Talk\Exceptions\CannotReachRemoteException;
 use OCA\Talk\Exceptions\ChatSummaryException;
+use OCA\Talk\Exceptions\ParticipantNotFoundException;
 use OCA\Talk\Federation\Authenticator;
 use OCA\Talk\GuestManager;
+use OCA\Talk\Manager;
 use OCA\Talk\MatterbridgeManager;
 use OCA\Talk\Middleware\Attribute\FederationSupported;
 use OCA\Talk\Middleware\Attribute\RequireAuthenticatedParticipant;
@@ -32,6 +34,7 @@ use OCA\Talk\Model\Attachment;
 use OCA\Talk\Model\Attendee;
 use OCA\Talk\Model\Bot;
 use OCA\Talk\Model\Message;
+use OCA\Talk\Model\Reminder;
 use OCA\Talk\Model\Session;
 use OCA\Talk\Participant;
 use OCA\Talk\ResponseDefinitions;
@@ -44,8 +47,7 @@ use OCA\Talk\Service\ProxyCacheMessageService;
 use OCA\Talk\Service\ReminderService;
 use OCA\Talk\Service\RoomFormatter;
 use OCA\Talk\Service\SessionService;
-use OCA\Talk\Share\Helper\FilesMetadataCache;
-use OCA\Talk\Share\RoomShareProvider;
+use OCA\Talk\Share\Helper\Preloader;
 use OCP\App\IAppManager;
 use OCP\AppFramework\Db\DoesNotExistException;
 use OCP\AppFramework\Http;
@@ -70,7 +72,6 @@ use OCP\RichObjectStrings\IValidator;
 use OCP\Security\ITrustedDomainHelper;
 use OCP\Security\RateLimiting\IRateLimitExceededException;
 use OCP\Share\Exceptions\ShareNotFound;
-use OCP\Share\IShare;
 use OCP\TaskProcessing\Exception\Exception;
 use OCP\TaskProcessing\IManager as ITaskProcessingManager;
 use OCP\TaskProcessing\Task;
@@ -85,6 +86,7 @@ use Psr\Log\LoggerInterface;
  * @psalm-import-type TalkChatMessage from ResponseDefinitions
  * @psalm-import-type TalkChatMessageWithParent from ResponseDefinitions
  * @psalm-import-type TalkChatReminder from ResponseDefinitions
+ * @psalm-import-type TalkChatReminderUpcoming from ResponseDefinitions
  * @psalm-import-type TalkRichObjectParameter from ResponseDefinitions
  * @psalm-import-type TalkRoom from ResponseDefinitions
  */
@@ -99,6 +101,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		private IUserManager $userManager,
 		private IAppManager $appManager,
 		private ChatManager $chatManager,
+		protected Manager $manager,
 		private RoomFormatter $roomFormatter,
 		private ReactionManager $reactionManager,
 		private ParticipantService $participantService,
@@ -108,8 +111,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 		protected ReminderService $reminderService,
 		private GuestManager $guestManager,
 		private MessageParser $messageParser,
-		protected RoomShareProvider $shareProvider,
-		protected FilesMetadataCache $filesMetadataCache,
+		protected Preloader $sharePreloader,
 		private IManager $autoCompleteManager,
 		private IUserStatusManager $statusManager,
 		protected MatterbridgeManager $matterbridgeManager,
@@ -338,38 +340,6 @@ class ChatController extends AEnvironmentAwareOCSController {
 		return $this->parseCommentToResponse($comment);
 	}
 
-	/*
-	 * Gather share IDs from the comments and preload share definitions
-	 * and files metadata to avoid separate database query for each
-	 * individual share/node later on.
-	 *
-	 * @param IComment[] $comments
-	 */
-	protected function preloadShares(array $comments): void {
-		// Scan messages for share IDs
-		$shareIds = [];
-		foreach ($comments as $comment) {
-			$verb = $comment->getVerb();
-			if ($verb === 'object_shared') {
-				$message = $comment->getMessage();
-				$data = json_decode($message, true);
-				if (isset($data['parameters']['share'])) {
-					$shareIds[] = $data['parameters']['share'];
-				}
-			}
-		}
-		if (!empty($shareIds)) {
-			// Retrieved Share objects will be cached by
-			// the RoomShareProvider and returned from the cache to
-			// the Parser\SystemMessage without additional database queries.
-			$shares = $this->shareProvider->getSharesByIds($shareIds);
-
-			// Preload files metadata as well
-			$fileIds = array_filter(array_map(static fn (IShare $share) => $share->getNodeId(), $shares));
-			$this->filesMetadataCache->preloadMetadata($fileIds);
-		}
-	}
-
 	/**
 	 * Receives chat messages from the given room
 	 *
@@ -546,14 +516,14 @@ class ChatController extends AEnvironmentAwareOCSController {
 		$currentUser = $this->userManager->get($this->userId);
 		$batchSize = $this->appConfig->getAppValueInt('ai_unread_summary_batch_size', 500);
 		$comments = $this->chatManager->waitForNewMessages($this->room, $fromMessageId, $batchSize, 0, $currentUser, true, false);
-		$this->preloadShares($comments);
+		$this->sharePreloader->preloadShares($comments);
 
 		$messages = [];
 		$nextOffset = 0;
 		foreach ($comments as $comment) {
 			$nextOffset = (int)$comment->getId();
 			$message = $this->messageParser->createMessage($this->room, $this->participant, $comment, $this->l);
-			$this->messageParser->parseMessage($message);
+			$this->messageParser->parseMessage($message, true);
 
 			if (!$message->getVisibility()) {
 				continue;
@@ -652,7 +622,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 			return new DataResponse(null, Http::STATUS_NOT_MODIFIED);
 		}
 
-		$this->preloadShares($comments);
+		$this->sharePreloader->preloadShares($comments);
 
 		$i = 0;
 		$now = $this->timeFactory->getDateTime();
@@ -1069,6 +1039,8 @@ class ChatController extends AEnvironmentAwareOCSController {
 	#[UserRateLimit(limit: 60, period: 3600)]
 	public function setReminder(int $messageId, int $timestamp): DataResponse {
 		try {
+			// FIXME fail 400 when reminder is after expiration
+			// And system messages
 			$this->validateMessageExists($messageId, sync: true);
 		} catch (DoesNotExistException) {
 			return new DataResponse(['error' => 'message'], Http::STATUS_NOT_FOUND);
@@ -1148,6 +1120,94 @@ class ChatController extends AEnvironmentAwareOCSController {
 		return new DataResponse([], Http::STATUS_OK);
 	}
 
+	/**
+	 * Get all upcoming reminders
+	 *
+	 * Required capability: `upcoming-reminders`
+	 *
+	 * @return DataResponse<Http::STATUS_OK, list<TalkChatReminderUpcoming>, array{}>
+	 *
+	 * 200: Reminders returned
+	 */
+	#[NoAdminRequired]
+	public function getUpcomingReminders(): DataResponse {
+		if ($this->userId === null) {
+			return new DataResponse([], Http::STATUS_OK);
+		}
+
+		$reminders = $this->reminderService->getUpcomingReminders($this->userId, Reminder::NUM_UPCOMING_REMINDERS);
+		if (empty($reminders)) {
+			return new DataResponse([], Http::STATUS_OK);
+		}
+
+		$tokens = array_unique(array_map(static fn (Reminder $reminder): string => $reminder->getToken(), $reminders));
+		$rooms = $this->manager->getRoomsForActor(Attendee::ACTOR_USERS, $this->userId, tokens: $tokens);
+		$roomMap = [];
+		foreach ($rooms as $room) {
+			if ($room->isFederatedConversation()) {
+				// FIXME Federated chats
+				continue;
+			}
+			$roomMap[$room->getToken()] = $room;
+		}
+
+		/** @var Reminder[] $reminders */
+		$reminders = array_filter($reminders, static fn (Reminder $reminder): bool => isset($roomMap[$reminder->getToken()]));
+		if (empty($reminders)) {
+			return new DataResponse([], Http::STATUS_OK);
+		}
+
+		$messageIds = array_map(static fn (Reminder $reminder): int => $reminder->getMessageId(), $reminders);
+		$comments = $this->chatManager->getMessagesById($messageIds);
+		$now = $this->timeFactory->getDateTime();
+
+		$resultData = [];
+		foreach ($reminders as $reminder) {
+			if (!isset($comments[$reminder->getMessageId()])) {
+				continue;
+			}
+			$comment = $comments[$reminder->getMessageId()];
+			$room = $roomMap[$reminder->getToken()];
+			try {
+				$participant = $this->participantService->getParticipant($room, $this->userId);
+			} catch (ParticipantNotFoundException) {
+				continue;
+			}
+
+			$message = $this->messageParser->createMessage($room, $participant, $comment, $this->l);
+			$this->messageParser->parseMessage($message);
+
+			$expireDate = $message->getExpirationDateTime();
+			if ($expireDate instanceof \DateTime && $expireDate < $now) {
+				continue;
+			}
+
+			if (!$message->getVisibility()) {
+				continue;
+			}
+
+			$data = $message->toArray($this->getResponseFormat());
+
+			if ($participant->getAttendee()->isSensitive()) {
+				$data['message'] = '';
+				$data['messageParameters'] = [];
+			}
+
+			$resultData[] = [
+				'reminderTimestamp' => $reminder->getDateTime()->getTimestamp(),
+				'roomToken' => $reminder->getToken(),
+				'messageId' => $reminder->getMessageId(),
+				'actorType' => $data['actorType'],
+				'actorId' => $data['actorId'],
+				'actorDisplayName' => $data['actorDisplayName'],
+				'message' => $data['message'],
+				'messageParameters' => $data['messageParameters'],
+			];
+		}
+
+		return new DataResponse($resultData, Http::STATUS_OK);
+	}
+
 	/**
 	 * @throws DoesNotExistException
 	 * @throws CannotReachRemoteException
@@ -1414,7 +1474,7 @@ class ChatController extends AEnvironmentAwareOCSController {
 	 */
 	protected function getMessagesForRoom(array $messageIds): array {
 		$comments = $this->chatManager->getMessagesForRoomById($this->room, $messageIds);
-		$this->preloadShares($comments);
+		$this->sharePreloader->preloadShares($comments);
 
 		$messages = [];
 		$comments = $this->chatManager->filterCommentsWithNonExistingFiles($comments);
