@@ -359,7 +359,7 @@ class Manager {
 	 * @param bool $includeLastMessage
 	 * @return Room[]
 	 */
-	public function getRoomsForActor(string $actorType, string $actorId, array $sessionIds = [], bool $includeLastMessage = false): array {
+	public function getRoomsForActor(string $actorType, string $actorId, array $sessionIds = [], bool $includeLastMessage = false, array $tokens = []): array {
 		$query = $this->db->getQueryBuilder();
 		$helper = new SelectHelper();
 		$helper->selectRoomsTable($query);
@@ -372,6 +372,10 @@ class Manager {
 			))
 			->where($query->expr()->isNotNull('a.id'));
 
+		if (!empty($tokens)) {
+			$query->andWhere($query->expr()->in('r.token', $query->createNamedParameter($tokens, IQueryBuilder::PARAM_STR_ARRAY)));
+		}
+
 		if (!empty($sessionIds)) {
 			$helper->selectSessionsTable($query);
 			$query->leftJoin('a', 'talk_sessions', 's', $query->expr()->andX(
@@ -942,6 +946,39 @@ class Manager {
 		return $rooms;
 	}
 
+	/**
+	 * @return list<Room>
+	 */
+	public function getExpiringRoomsForObjectType(string $objectType, int $minimumLastActivity): array {
+		$query = $this->db->getQueryBuilder();
+		$helper = new SelectHelper();
+		$helper->selectRoomsTable($query, '');
+		$query->from('talk_rooms')
+			->where($query->expr()->eq('object_type', $query->createNamedParameter($objectType)))
+			->andWhere($query->expr()->lte('last_activity', $query->createNamedParameter(new \DateTimeImmutable('@' . $minimumLastActivity), IQueryBuilder::PARAM_DATETIME_IMMUTABLE)));
+
+		if ($objectType === Room::OBJECT_TYPE_EVENT) {
+			// Ignore events that don't have a start and end date,
+			// as they are most likely from before the Talk 21.1 upgrade
+			$query->andWhere($query->expr()->like('object_id', $query->createNamedParameter('%' . $this->db->escapeLikeParameter('#') . '%')));
+		}
+
+		$result = $query->executeQuery();
+
+		$rooms = [];
+		while ($row = $result->fetch()) {
+			if ($row['token'] === null) {
+				// FIXME Temporary solution for the Talk6 release
+				continue;
+			}
+
+			$rooms[] = $this->createRoomObject($row);
+		}
+		$result->closeCursor();
+
+		return $rooms;
+	}
+
 	/**
 	 * @param string[] $tokens
 	 * @return array<string, Room>
@@ -1074,7 +1111,7 @@ class Manager {
 		$result->closeCursor();
 
 		if ($row === false) {
-			$room = $this->createRoom(Room::TYPE_CHANGELOG, $userId);
+			$room = $this->createRoom(Room::TYPE_CHANGELOG, $userId, sipEnabled: Webinary::SIP_DISABLED);
 			Server::get(RoomService::class)->setReadOnly($room, Room::READ_ONLY);
 
 			$user = $this->userManager->get($userId);
@@ -1102,16 +1139,32 @@ class Manager {
 		return $room;
 	}
 
-	/**
-	 * @param int $type
-	 * @param string $name
-	 * @param string $objectType
-	 * @param string $objectId
-	 * @param string $password
-	 * @return Room
-	 */
-	public function createRoom(int $type, string $name = '', string $objectType = '', string $objectId = '', string $password = ''): Room {
+	public function createRoom(
+		int $type,
+		string $name = '',
+		string $objectType = '',
+		string $objectId = '',
+		string $password = '',
+		?int $readOnly = null,
+		?int $listable = null,
+		?int $messageExpiration = null,
+		?int $lobbyState = null,
+		?\DateTime $lobbyTimer = null,
+		?int $sipEnabled = null,
+		?int $permissions = null,
+		?int $recordingConsent = null,
+		?int $mentionPermissions = null,
+		?string $description = null,
+	): Room {
 		$token = $this->getNewToken();
+		$row = [
+			'name' => $name,
+			'type' => $type,
+			'token' => $token,
+			'object_type' => $objectType,
+			'object_id' => $objectId,
+			'password' => $password,
+		];
 
 		$insert = $this->db->getQueryBuilder();
 		$insert->insert('talk_rooms')
@@ -1129,17 +1182,59 @@ class Manager {
 				->setValue('object_id', $insert->createNamedParameter($objectId));
 		}
 
+		if ($readOnly !== null) {
+			$insert->setValue('read_only', $insert->createNamedParameter($readOnly, IQueryBuilder::PARAM_INT));
+			$row['read_only'] = $readOnly;
+		}
+		if ($listable !== null) {
+			$insert->setValue('listable', $insert->createNamedParameter($listable, IQueryBuilder::PARAM_INT));
+			$row['listable'] = $listable;
+		}
+		if ($messageExpiration !== null) {
+			$insert->setValue('message_expiration', $insert->createNamedParameter($messageExpiration, IQueryBuilder::PARAM_INT));
+			$row['message_expiration'] = $messageExpiration;
+		}
+		if ($lobbyState !== null) {
+			$insert->setValue('lobby_state', $insert->createNamedParameter($lobbyState, IQueryBuilder::PARAM_INT));
+			$row['lobby_state'] = $lobbyState;
+			if ($lobbyTimer !== null) {
+				$insert->setValue('lobby_timer', $insert->createNamedParameter($lobbyTimer, IQueryBuilder::PARAM_DATETIME_MUTABLE));
+				$row['lobby_timer'] = $lobbyTimer->format(\DATE_ATOM);
+			}
+		}
+		if ($sipEnabled === null) {
+			$default = $this->config->getAppValue('spreed', 'sip_dialin_default', 'none');
+			if ($default !== 'none') {
+				$default = (int)$default;
+				if (in_array($default, [Webinary::SIP_DISABLED, Webinary::SIP_ENABLED, Webinary::SIP_ENABLED_NO_PIN], true)) {
+					$sipEnabled = $default;
+				}
+			}
+		}
+		if ($sipEnabled !== null) {
+			$insert->setValue('sip_enabled', $insert->createNamedParameter($sipEnabled, IQueryBuilder::PARAM_INT));
+			$row['sip_enabled'] = $sipEnabled;
+		}
+		if ($permissions !== null) {
+			$insert->setValue('default_permissions', $insert->createNamedParameter($permissions, IQueryBuilder::PARAM_INT));
+			$row['default_permissions'] = $permissions;
+		}
+		if ($recordingConsent !== null) {
+			$insert->setValue('recording_consent', $insert->createNamedParameter($recordingConsent, IQueryBuilder::PARAM_INT));
+			$row['recording_consent'] = $recordingConsent;
+		}
+		if ($mentionPermissions !== null) {
+			$insert->setValue('mention_permissions', $insert->createNamedParameter($mentionPermissions, IQueryBuilder::PARAM_INT));
+			$row['mention_permissions'] = $mentionPermissions;
+		}
+		if ($description !== null) {
+			$insert->setValue('description', $insert->createNamedParameter($description));
+			$row['description'] = $description;
+		}
+
 		$insert->executeStatement();
-		$roomId = $insert->getLastInsertId();
-		$room = $this->createRoomObjectFromData([
-			'r_id' => $roomId,
-			'name' => $name,
-			'type' => $type,
-			'token' => $token,
-			'object_type' => $objectType,
-			'object_id' => $objectId,
-			'password' => $password
-		]);
+		$row['r_id'] = $insert->getLastInsertId();
+		$room = $this->createRoomObjectFromData($row);
 
 		$event = new RoomCreatedEvent($room);
 		$this->dispatcher->dispatchTyped($event);
