@@ -2,45 +2,28 @@
 
 declare(strict_types=1);
 /**
- * @copyright Copyright (c) 2019 Joas Schilling <coding@schilljs.com>
- *
- * @license GNU AGPL version 3 or any later version
- *
- * This program is free software: you can redistribute it and/or modify
- * it under the terms of the GNU Affero General Public License as
- * published by the Free Software Foundation, either version 3 of the
- * License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU Affero General Public License for more details.
- *
- * You should have received a copy of the GNU Affero General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
- *
+ * SPDX-FileCopyrightText: 2019 Nextcloud GmbH and Nextcloud contributors
+ * SPDX-License-Identifier: AGPL-3.0-or-later
  */
 
 namespace OCA\Talk\Model;
 
 use OCA\Talk\Chat\ChatManager;
 use OCA\Talk\Participant;
+use OCA\Talk\ResponseDefinitions;
 use OCA\Talk\Room;
 use OCP\Comments\IComment;
 use OCP\IL10N;
 
+/**
+ * @psalm-import-type TalkChatMessage from ResponseDefinitions
+ */
 class Message {
-	/** @var Room */
-	protected $room;
-
-	/** @var IComment */
-	protected $comment;
-
-	/** @var IL10N */
-	protected $l;
-
-	/** @var Participant */
-	protected $participant;
+	public const METADATA_LAST_EDITED_BY_TYPE = 'last_edited_by_type';
+	public const METADATA_LAST_EDITED_BY_ID = 'last_edited_by_id';
+	public const METADATA_LAST_EDITED_TIME = 'last_edited_time';
+	public const METADATA_SILENT = 'silent';
+	public const METADATA_CAN_MENTION_ALL = 'can_mention_all';
 
 	/** @var bool */
 	protected $visible = true;
@@ -66,14 +49,25 @@ class Message {
 	/** @var string */
 	protected $actorDisplayName = '';
 
-	public function __construct(Room $room,
-		Participant $participant,
-		IComment $comment,
-		IL10N $l) {
-		$this->room = $room;
-		$this->participant = $participant;
-		$this->comment = $comment;
-		$this->l = $l;
+	/** @var string */
+	protected $lastEditActorType = '';
+
+	/** @var string */
+	protected $lastEditActorId = '';
+
+	/** @var string */
+	protected $lastEditActorDisplayName = '';
+
+	/** @var int */
+	protected $lastEditTimestamp = 0;
+
+	public function __construct(
+		protected Room $room,
+		protected ?Participant $participant,
+		protected ?IComment $comment,
+		protected IL10N $l,
+		protected ?ProxyCacheMessage $proxy = null,
+	) {
 	}
 
 	/*
@@ -84,7 +78,7 @@ class Message {
 		return $this->room;
 	}
 
-	public function getComment(): IComment {
+	public function getComment(): ?IComment {
 		return $this->comment;
 	}
 
@@ -92,7 +86,7 @@ class Message {
 		return $this->l;
 	}
 
-	public function getParticipant(): Participant {
+	public function getParticipant(): ?Participant {
 		return $this->participant;
 	}
 
@@ -100,6 +94,14 @@ class Message {
 	 * Parsed message information
 	 */
 
+	public function getMessageId(): int {
+		return $this->comment ? (int)$this->comment->getId() : $this->proxy->getRemoteMessageId();
+	}
+
+	public function getExpirationDateTime(): ?\DateTimeInterface {
+		return $this->comment ? $this->comment->getExpireDate() : $this->proxy->getExpirationDatetime();
+	}
+
 	public function setVisibility(bool $visible): void {
 		$this->visible = $visible;
 	}
@@ -140,6 +142,13 @@ class Message {
 		$this->actorDisplayName = $displayName;
 	}
 
+	public function setLastEdit(string $type, string $id, string $displayName, int $timestamp): void {
+		$this->lastEditActorType = $type;
+		$this->lastEditActorId = $id;
+		$this->lastEditActorDisplayName = $displayName;
+		$this->lastEditTimestamp = $timestamp;
+	}
+
 	public function getActorType(): string {
 		return $this->actorType;
 	}
@@ -161,13 +170,19 @@ class Message {
 			$this->getMessageType() !== ChatManager::VERB_MESSAGE_DELETED &&
 			$this->getMessageType() !== ChatManager::VERB_REACTION &&
 			$this->getMessageType() !== ChatManager::VERB_REACTION_DELETED &&
-			\in_array($this->getActorType(), [Attendee::ACTOR_USERS, Attendee::ACTOR_GUESTS]);
+			\in_array($this->getActorType(), [
+				Attendee::ACTOR_USERS,
+				Attendee::ACTOR_FEDERATED_USERS,
+				Attendee::ACTOR_GUESTS,
+				Attendee::ACTOR_EMAILS,
+				Attendee::ACTOR_BOTS,
+			], true);
 	}
 
 	/**
 	 * @param string $format
 	 * @psalm-param 'json'|'xml' $format
-	 * @return array
+	 * @return TalkChatMessage
 	 */
 	public function toArray(string $format): array {
 		$expireDate = $this->getComment()->getExpireDate();
@@ -180,7 +195,7 @@ class Message {
 		}
 
 		$data = [
-			'id' => (int) $this->getComment()->getId(),
+			'id' => (int)$this->getComment()->getId(),
 			'token' => $this->getRoom()->getToken(),
 			'actorType' => $this->getActorType(),
 			'actorId' => $this->getActorId(),
@@ -191,15 +206,28 @@ class Message {
 			'systemMessage' => $this->getMessageType() === ChatManager::VERB_SYSTEM ? $this->getMessageRaw() : '',
 			'messageType' => $this->getMessageType(),
 			'isReplyable' => $this->isReplyable(),
-			'referenceId' => (string) $this->getComment()->getReferenceId(),
+			'referenceId' => (string)$this->getComment()->getReferenceId(),
 			'reactions' => $reactions,
 			'expirationTimestamp' => $expireDate ? $expireDate->getTimestamp() : 0,
+			'markdown' => $this->getMessageType() === ChatManager::VERB_SYSTEM ? false : true,
 		];
 
+		if ($this->lastEditActorType && $this->lastEditActorId && $this->lastEditTimestamp) {
+			$data['lastEditActorType'] = $this->lastEditActorType;
+			$data['lastEditActorId'] = $this->lastEditActorId;
+			$data['lastEditActorDisplayName'] = $this->lastEditActorDisplayName;
+			$data['lastEditTimestamp'] = $this->lastEditTimestamp;
+		}
+
 		if ($this->getMessageType() === ChatManager::VERB_MESSAGE_DELETED) {
 			$data['deleted'] = true;
 		}
 
+		$metaData = $this->comment->getMetaData() ?? [];
+		if (!empty($metaData[self::METADATA_SILENT])) {
+			$data[self::METADATA_SILENT] = true;
+		}
+
 		return $data;
 	}
 }
